@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.9.5"
+    version = "1.9.7"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -69,10 +69,10 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
                 "name": "number_alarm",
                 "label": "告警次数",
                 "type": "number",
-                "placeholder": "告警次数阀值",
+                "placeholder": "1",
                 "required": False,
                 "default": self.set_default(
-                    project, "number_alarm", "1"
+                    project, "number_alarm", "DINGTALK_NUMBER_ALARM"
                 ),
             },
             {
@@ -118,9 +118,9 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         custom_keyword = self.get_option("custom_keyword", project)
         # 告警次数阀值
-        number_alarm = self.get_option("number_alarm", project)
+        number_alarm = self.get_option("number_alarm", project) if self.get_option("number_alarm", project) else 1
         phones = self.get_option("phones", project)
-
+        #
         issue_link = group.get_absolute_url(params={"referrer": "dingtalknotify"})
         issue_link = issue_link.replace('https', 'http')
 
@@ -129,6 +129,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"{payload} > 出现次数: {group.times_seen} \n\n"
         payload = f"{payload} > 查看详情: <font color=blue>[{'Error: ' + group.message[0:50]}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
+        # payload = f"{payload} > 告警次数: {number_alarm} \n\n"
         # payload = f"{payload} > Hi: {event.__dict__} \n\n"
         # payload = f"{payload} > Hi: {event.data} \n\n"
 
@@ -163,6 +164,6 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         }
         # 0 - 状态为未解决，并且次数大于设定值，才告警通知，并且分配为空
         # if group.status == 0 and group.times_seen > number_alarm and not bool(event.data):
-        if int(group.status) == 0 and int(group.times_seen) >= int(number_alarm):
+        if group.status == 0 and group.times_seen >= number_alarm:
             for webhook_url in self.get_webhook_urls(group.project):
                 requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
